@@ -10,7 +10,7 @@ from openstf.tasks.utils.taskcontext import TaskContext
 
 
 def main():
-    with TaskContext(__file__) as context:
+    with TaskContext("create_capacity_forecast") as context:
         # prediction horizons
         y_hor = list(range(13))
 
